==> simde_0.6.0.orig.tar.gz: simde-0.6.0/test/arm/neon/declare-suites.h <==
SIMDE_TEST_DECLARE_SUITE(abd)
SIMDE_TEST_DECLARE_SUITE(abs)
SIMDE_TEST_DECLARE_SUITE(add)
SIMDE_TEST_DECLARE_SUITE(addl)
SIMDE_TEST_DECLARE_SUITE(addl_high)
SIMDE_TEST_DECLARE_SUITE(addw)
SIMDE_TEST_DECLARE_SUITE(and)
SIMDE_TEST_DECLARE_SUITE(bsl)
SIMDE_TEST_DECLARE_SUITE(cagt)
SIMDE_TEST_DECLARE_SUITE(ceq)
SIMDE_TEST_DECLARE_SUITE(ceqz)
SIMDE_TEST_DECLARE_SUITE(cge)
SIMDE_TEST_DECLARE_SUITE(cgez)
SIMDE_TEST_DECLARE_SUITE(cgt)
SIMDE_TEST_DECLARE_SUITE(cgtz)
SIMDE_TEST_DECLARE_SUITE(cle)
SIMDE_TEST_DECLARE_SUITE(clez)
SIMDE_TEST_DECLARE_SUITE(clt)
SIMDE_TEST_DECLARE_SUITE(cltz)
SIMDE_TEST_DECLARE_SUITE(cvt)
SIMDE_TEST_DECLARE_SUITE(combine)
SIMDE_TEST_DECLARE_SUITE(create)
SIMDE_TEST_DECLARE_SUITE(dot)
SIMDE_TEST_DECLARE_SUITE(dot_lane)
SIMDE_TEST_DECLARE_SUITE(dup_n)
SIMDE_TEST_DECLARE_SUITE(eor)
SIMDE_TEST_DECLARE_SUITE(ext)
SIMDE_TEST_DECLARE_SUITE(get_high)
SIMDE_TEST_DECLARE_SUITE(get_lane)
SIMDE_TEST_DECLARE_SUITE(get_low)
SIMDE_TEST_DECLARE_SUITE(max)
SIMDE_TEST_DECLARE_SUITE(min)
SIMDE_TEST_DECLARE_SUITE(mla)
SIMDE_TEST_DECLARE_SUITE(mla_n)
SIMDE_TEST_DECLARE_SUITE(mlal)
SIMDE_TEST_DECLARE_SUITE(mlal_high)
SIMDE_TEST_DECLARE_SUITE(movl)
SIMDE_TEST_DECLARE_SUITE(movl_high)
SIMDE_TEST_DECLARE_SUITE(movn)
SIMDE_TEST_DECLARE_SUITE(mul)
SIMDE_TEST_DECLARE_SUITE(mul_n)
SIMDE_TEST_DECLARE_SUITE(mull)
SIMDE_TEST_DECLARE_SUITE(mull_n)
SIMDE_TEST_DECLARE_SUITE(mvn)
SIMDE_TEST_DECLARE_SUITE(neg)
SIMDE_TEST_DECLARE_SUITE(orr)
SIMDE_TEST_DECLARE_SUITE(padal)
SIMDE_TEST_DECLARE_SUITE(padd)
SIMDE_TEST_DECLARE_SUITE(paddl)
SIMDE_TEST_DECLARE_SUITE(pmax)
SIMDE_TEST_DECLARE_SUITE(pmin)
SIMDE_TEST_DECLARE_SUITE(qadd)
SIMDE_TEST_DECLARE_SUITE(qdmulh)
SIMDE_TEST_DECLARE_SUITE(qdmull)
SIMDE_TEST_DECLARE_SUITE(qrdmulh)
SIMDE_TEST_DECLARE_SUITE(qrdmulh_n)
SIMDE_TEST_DECLARE_SUITE(qmovn)
SIMDE_TEST_DECLARE_SUITE(qmovn_high)
SIMDE_TEST_DECLARE_SUITE(qmovun)
SIMDE_TEST_DECLARE_SUITE(qtbl)
SIMDE_TEST_DECLARE_SUITE(qtbx)
SIMDE_TEST_DECLARE_SUITE(rbit)
SIMDE_TEST_DECLARE_SUITE(reinterpret)
SIMDE_TEST_DECLARE_SUITE(rev16)
SIMDE_TEST_DECLARE_SUITE(rev32)
SIMDE_TEST_DECLARE_SUITE(rev64)
SIMDE_TEST_DECLARE_SUITE(rhadd)
SIMDE_TEST_DECLARE_SUITE(rshl)
SIMDE_TEST_DECLARE_SUITE(rshr_n)
SIMDE_TEST_DECLARE_SUITE(rsra_n)
SIMDE_TEST_DECLARE_SUITE(set_lane)
SIMDE_TEST_DECLARE_SUITE(st1_lane)
SIMDE_TEST_DECLARE_SUITE(st3)
SIMDE_TEST_DECLARE_SUITE(st4)
SIMDE_TEST_DECLARE_SUITE(shl)
SIMDE_TEST_DECLARE_SUITE(shl_n)
SIMDE_TEST_DECLARE_SUITE(shr_n)
SIMDE_TEST_DECLARE_SUITE(sra_n)
SIMDE_TEST_DECLARE_SUITE(sub)
SIMDE_TEST_DECLARE_SUITE(subl)
SIMDE_TEST_DECLARE_SUITE(tbl)
SIMDE_TEST_DECLARE_SUITE(tbx)
SIMDE_TEST_DECLARE_SUITE(trn)
SIMDE_TEST_DECLARE_SUITE(trn1)
SIMDE_TEST_DECLARE_SUITE(trn2)
SIMDE_TEST_DECLARE_SUITE(tst)
SIMDE_TEST_DECLARE_SUITE(uzp)
SIMDE_TEST_DECLARE_SUITE(uzp1)
SIMDE_TEST_DECLARE_SUITE(uzp2)
SIMDE_TEST_DECLARE_SUITE(zip)
SIMDE_TEST_DECLARE_SUITE(zip1)
SIMDE_TEST_DECLARE_SUITE(zip2)

==> simde_0.7.0.orig.tar.gz: simde-0.7.0/test/arm/neon/declare-suites.h <==
SIMDE_TEST_DECLARE_SUITE(aba)
SIMDE_TEST_DECLARE_SUITE(abd)
SIMDE_TEST_DECLARE_SUITE(abdl)
SIMDE_TEST_DECLARE_SUITE(abs)
SIMDE_TEST_DECLARE_SUITE(add)
SIMDE_TEST_DECLARE_SUITE(addl)
SIMDE_TEST_DECLARE_SUITE(addl_high)
SIMDE_TEST_DECLARE_SUITE(addv)
SIMDE_TEST_DECLARE_SUITE(addlv)
SIMDE_TEST_DECLARE_SUITE(addw)
SIMDE_TEST_DECLARE_SUITE(addw_high)
SIMDE_TEST_DECLARE_SUITE(and)
SIMDE_TEST_DECLARE_SUITE(bic)
SIMDE_TEST_DECLARE_SUITE(bsl)
SIMDE_TEST_DECLARE_SUITE(cagt)
SIMDE_TEST_DECLARE_SUITE(ceq)
SIMDE_TEST_DECLARE_SUITE(ceqz)
SIMDE_TEST_DECLARE_SUITE(cge)
SIMDE_TEST_DECLARE_SUITE(cgez)
SIMDE_TEST_DECLARE_SUITE(cgt)
SIMDE_TEST_DECLARE_SUITE(cgtz)
SIMDE_TEST_DECLARE_SUITE(cle)
SIMDE_TEST_DECLARE_SUITE(clez)
SIMDE_TEST_DECLARE_SUITE(cls)
SIMDE_TEST_DECLARE_SUITE(clt)
SIMDE_TEST_DECLARE_SUITE(cltz)
SIMDE_TEST_DECLARE_SUITE(clz)
SIMDE_TEST_DECLARE_SUITE(cnt)
SIMDE_TEST_DECLARE_SUITE(cvt)
SIMDE_TEST_DECLARE_SUITE(combine)
SIMDE_TEST_DECLARE_SUITE(create)
SIMDE_TEST_DECLARE_SUITE(dot)
SIMDE_TEST_DECLARE_SUITE(dot_lane)
SIMDE_TEST_DECLARE_SUITE(dup_n)
SIMDE_TEST_DECLARE_SUITE(dup_lane)
SIMDE_TEST_DECLARE_SUITE(eor)
SIMDE_TEST_DECLARE_SUITE(ext)
SIMDE_TEST_DECLARE_SUITE(get_high)
SIMDE_TEST_DECLARE_SUITE(get_lane)
SIMDE_TEST_DECLARE_SUITE(get_low)
SIMDE_TEST_DECLARE_SUITE(hadd)
SIMDE_TEST_DECLARE_SUITE(hsub)
SIMDE_TEST_DECLARE_SUITE(max)
SIMDE_TEST_DECLARE_SUITE(maxnm)
SIMDE_TEST_DECLARE_SUITE(maxv)
SIMDE_TEST_DECLARE_SUITE(min)
SIMDE_TEST_DECLARE_SUITE(minnm)
SIMDE_TEST_DECLARE_SUITE(minv)
SIMDE_TEST_DECLARE_SUITE(mla)
SIMDE_TEST_DECLARE_SUITE(mla_n)
SIMDE_TEST_DECLARE_SUITE(mlal)
SIMDE_TEST_DECLARE_SUITE(mlal_high)
SIMDE_TEST_DECLARE_SUITE(mlal_n)
SIMDE_TEST_DECLARE_SUITE(mls)
SIMDE_TEST_DECLARE_SUITE(mlsl)
SIMDE_TEST_DECLARE_SUITE(mlsl_high)
SIMDE_TEST_DECLARE_SUITE(mlsl_n)
SIMDE_TEST_DECLARE_SUITE(movl)
SIMDE_TEST_DECLARE_SUITE(movl_high)
SIMDE_TEST_DECLARE_SUITE(movn)
SIMDE_TEST_DECLARE_SUITE(movn_high)
SIMDE_TEST_DECLARE_SUITE(mul)
SIMDE_TEST_DECLARE_SUITE(mul_lane)
SIMDE_TEST_DECLARE_SUITE(mul_n)
SIMDE_TEST_DECLARE_SUITE(mull)
SIMDE_TEST_DECLARE_SUITE(mull_high)
SIMDE_TEST_DECLARE_SUITE(mull_n)
SIMDE_TEST_DECLARE_SUITE(mvn)
SIMDE_TEST_DECLARE_SUITE(neg)
SIMDE_TEST_DECLARE_SUITE(orn)
SIMDE_TEST_DECLARE_SUITE(orr)
SIMDE_TEST_DECLARE_SUITE(padal)
SIMDE_TEST_DECLARE_SUITE(padd)
SIMDE_TEST_DECLARE_SUITE(paddl)
SIMDE_TEST_DECLARE_SUITE(pmax)
SIMDE_TEST_DECLARE_SUITE(pmin)
SIMDE_TEST_DECLARE_SUITE(qabs)
SIMDE_TEST_DECLARE_SUITE(qadd)
SIMDE_TEST_DECLARE_SUITE(qdmulh)
SIMDE_TEST_DECLARE_SUITE(qdmull)
SIMDE_TEST_DECLARE_SUITE(qrdmulh)
SIMDE_TEST_DECLARE_SUITE(qrdmulh_n)
SIMDE_TEST_DECLARE_SUITE(qmovn)
SIMDE_TEST_DECLARE_SUITE(qmovn_high)
SIMDE_TEST_DECLARE_SUITE(qmovun)
SIMDE_TEST_DECLARE_SUITE(qneg)
SIMDE_TEST_DECLARE_SUITE(qshl)
SIMDE_TEST_DECLARE_SUITE(qsub)
SIMDE_TEST_DECLARE_SUITE(qtbl)
SIMDE_TEST_DECLARE_SUITE(qtbx)
SIMDE_TEST_DECLARE_SUITE(rbit)
SIMDE_TEST_DECLARE_SUITE(reinterpret)
SIMDE_TEST_DECLARE_SUITE(rev16)
SIMDE_TEST_DECLARE_SUITE(rev32)
SIMDE_TEST_DECLARE_SUITE(rev64)
SIMDE_TEST_DECLARE_SUITE(rhadd)
SIMDE_TEST_DECLARE_SUITE(rnd)
SIMDE_TEST_DECLARE_SUITE(rshl)
SIMDE_TEST_DECLARE_SUITE(rshr_n)
SIMDE_TEST_DECLARE_SUITE(rsra_n)
SIMDE_TEST_DECLARE_SUITE(set_lane)
SIMDE_TEST_DECLARE_SUITE(st1_lane)
SIMDE_TEST_DECLARE_SUITE(st3)
SIMDE_TEST_DECLARE_SUITE(st4)
SIMDE_TEST_DECLARE_SUITE(shl)
SIMDE_TEST_DECLARE_SUITE(shl_n)
SIMDE_TEST_DECLARE_SUITE(shr_n)
SIMDE_TEST_DECLARE_SUITE(sra_n)
SIMDE_TEST_DECLARE_SUITE(sub)
SIMDE_TEST_DECLARE_SUITE(subl)
SIMDE_TEST_DECLARE_SUITE(subw)
SIMDE_TEST_DECLARE_SUITE(subw_high)
SIMDE_TEST_DECLARE_SUITE(tbl)
SIMDE_TEST_DECLARE_SUITE(tbx)
SIMDE_TEST_DECLARE_SUITE(trn)
SIMDE_TEST_DECLARE_SUITE(trn1)
SIMDE_TEST_DECLARE_SUITE(trn2)
SIMDE_TEST_DECLARE_SUITE(tst)
SIMDE_TEST_DECLARE_SUITE(uqadd)
SIMDE_TEST_DECLARE_SUITE(uzp)
SIMDE_TEST_DECLARE_SUITE(uzp1)
SIMDE_TEST_DECLARE_SUITE(uzp2)
SIMDE_TEST_DECLARE_SUITE(zip)
SIMDE_TEST_DECLARE_SUITE(zip1)
SIMDE_TEST_DECLARE_SUITE(zip2)
